import { ForceIgnore } from './forceIgnore';
import { TreeContainer } from './treeContainers';
import { MetadataComponent, VirtualDirectory } from './types';
import { JsonMap } from '@salesforce/ts-types';
import { SfdxFileFormat } from '../convert';
import { MetadataType } from '../registry';
export declare type ComponentProperties = {
    name: string;
    type: MetadataType;
    xml?: string;
    content?: string;
    parent?: SourceComponent;
    parentType?: MetadataType;
};
/**
 * Representation of a MetadataComponent in a file tree.
 */
export declare class SourceComponent implements MetadataComponent {
    readonly name: string;
    readonly type: MetadataType;
    readonly xml?: string;
    readonly parent?: SourceComponent;
    parentType?: MetadataType;
    content?: string;
    private _tree;
    private forceIgnore;
    private markedForDelete;
    constructor(props: ComponentProperties, tree?: TreeContainer, forceIgnore?: ForceIgnore);
    static createVirtualComponent(props: ComponentProperties, fs: VirtualDirectory[], forceIgnore?: ForceIgnore): SourceComponent;
    walkContent(): string[];
    /**
     * returns the children of a parent SourceComponent
     *
     * Ensures that the children of SourceComponent are valid child types.
     * Invalid child types can occur when projects are structured in an atypical way such as having
     * ApexClasses or Layouts within a CustomObject folder.
     *
     * @return SourceComponent[] containing valid children
     */
    getChildren(): SourceComponent[];
    parseXml<T = JsonMap>(): Promise<T>;
    parseXmlSync<T = JsonMap>(): T;
    getPackageRelativePath(fsPath: string, format: SfdxFileFormat): string;
    /**
     * @returns whether this component should be part of destructive changes.
     */
    isMarkedForDelete(): boolean;
    setMarkedForDelete(asDeletion: boolean): void;
    private calculateRelativePath;
    private parse;
    private getDecomposedChildren;
    private getNonDecomposedChildren;
    private walk;
    get fullName(): string;
    get tree(): TreeContainer;
    /**
     * Returns whether this component type is supported by the Metadata API
     * and therefore should have an entry added to the manifest.
     *
     * This is defined on the type in the registry. The type is required to
     * be in the registry for proper classification and for possible use in
     * decomposition/recomposition.
     *
     * Default value is true, so the only way to return false is to explicitly
     * set it in the registry as false.
     *
     * E.g., CustomFieldTranslation.
     */
    get isAddressable(): boolean;
}
